@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: css-text
 version: 0.1.2.1
-id: css-text-0.1.2.1-d1e175085ae55e4b9482a244b4d6aeb3
-key: csste_DadHJP15obR6JNRFmE5iId
+id: css-text-0.1.2.1-5f08c8634ff151127fcfba990f98863f
+key: csste_BKK1KtEb1sJ9s7LwxLpwLq
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -18,11 +18,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/css-text-0.1.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/css-text-0.1.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/css-text-0.1.2.1
-hs-libraries: HScss-text-0.1.2.1-DadHJP15obR6JNRFmE5iId
+hs-libraries: HScss-text-0.1.2.1-BKK1KtEb1sJ9s7LwxLpwLq
 depends:
-    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
+    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
 haddock-interfaces: /usr/share/doc/haskell-css-text/html/css-text.haddock
 haddock-html: /usr/share/doc/haskell-css-text/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
